@@ -6,7 +6,7 @@ from urllib.parse import urlparse
 import requests
 
 from huawei_lte_api.Session import Session
-from huawei_lte_api.api.User import UserSession
+from huawei_lte_api.api.User import DEFAULT_USERNAME, UserSession
 
 
 class Connection(Session):
@@ -24,11 +24,11 @@ class Connection(Session):
         parsed_url = urlparse(url)
 
         # User login code
-        username = username if username else parsed_url.username
+        username = username or parsed_url.username or DEFAULT_USERNAME
         password = password if password else parsed_url.password
 
         super().__init__(url, timeout=timeout, requests_session=requests_session)
-        self.user_session = UserSession(self, username, password) if username else None
+        self.user_session = UserSession(self, username, password) if username or password else None
 
         if login_on_demand:
             warnings.warn(
@@ -40,7 +40,7 @@ class Connection(Session):
         if self.user_session:
             try:
                 self.user_session.close()
-            except:
+            except:  # noqa: E722
                 super().close()
                 raise
         super().close()
